@@ -92,7 +92,7 @@ function(x                       ,
            mgp = c( 2.5 , 1 , 0 ),
            type = "n",', final_para, ')')))
       #magaxis(grid = TRUE, frame.plot = TRUE)
-      eval(parse(text = paste('magaxis(grid = TRUE, frame.plot = TRUE,',final_para,')')));
+      eval(parse(text = paste('magaxis(grid = FALSE, frame.plot = TRUE,',final_para,')')));
       #xtick = seq(from = xlim[1], to = xlim[2],5)
       #axis(side = 1, at = xtick, labels = NULL, xlim = xlim, log = "x")
       if (TRUE == confidence) {
@@ -143,14 +143,21 @@ function(x                       ,
       f_non <- x$f[non_zero]
       d     <- density(f_non)
       ok_d  <- d$x > 0
+      max_x <- max(d$x[ok_d])
+      min_x <- min(d$x[ok_d])
       
       #layout(cbind(1,2), width = c(4,1))
       plot(d$x[ok_d] , d$y[ok_d], col  = 2 , log = "x", lwd = 0, main = "", 
-           xlab = "Fitness", ylab = "Density",
-           cex.axis = 1 , cex.lab = 1, 
-           mgp = c( 2.5 , 1 , 0 ), axes = FALSE,
+           xlab = "Fitness", ylab = "Density",xlim = c(min_x,max_x),
+           mgp = c( 2.5 , 1 , 0 ), 
+           axes = FALSE,
            pch = "",...)
-      magaxis(grid = TRUE, frame.plot = TRUE)
+      axis(side = 1, at=c(format(round(min_x, 2), nsmall = 2),
+                          format(round(1, 2), nsmall = 2),
+                          format(round(max_x, 2), nsmall = 2)),
+           tcl = 0.5, ...)
+      magaxis(side = 2,grid = FALSE, frame.plot = TRUE,
+              logpretty = FALSE,...)
       
       #x <- c(format(min(f_non),digits = 1),1,5,10,15,format(max(f_non),digits = 4))
       u    <- smooth.spline(d$x, d$y, spar = 0.01)
@@ -244,7 +251,7 @@ function(x                       ,
                  	mgp = c( 2.5 , 1 , 0 ) ,', 
                                   final_para, ')')))
           #magaxis(grid = TRUE, frame.plot = TRUE)
-          eval(parse(text = paste('magaxis(grid = TRUE, frame.plot = TRUE,',final_para,')')));
+          eval(parse(text = paste('magaxis(grid = FALSE, frame.plot = TRUE,',final_para,')')));
           
          
           if (TRUE == confidence) {
