@@ -5,6 +5,6 @@ print.PA_result <- function(x,...){
   cat("Estimated attachment exponent:", x$alpha, "\n");
   if (x$ci[1] == "N") {
     cat("No possible confidence interval for the estimated attachment exponent.\n");
-  } else cat("95% confidence interval of the attachment exponent: (", x$ci[1], ",", 
+  } else cat("Two-sigma confidence interval of the attachment exponent: (", x$ci[1], ",", 
               x$ci[2],")\n");
 }
\ No newline at end of file
