@@ -4,6 +4,6 @@ summary.PA_result <- function(object,...){
   cat("Estimated attachment exponent:", object$alpha, "\n");
   if (object$ci[1] == "N") {
       cat("No possible confidence interval for the estimated attachment exponent.\n");
-  } else cat("95% confidence interval of the attachment exponent: (", object$ci[1], ",", 
+  } else cat("Two-sigma confidence interval of the attachment exponent: (", object$ci[1], ",", 
        object$ci[2],")\n");
 }
\ No newline at end of file
