@@ -13,7 +13,7 @@ i      <- 1
 
 net  <- generate_net(N = 100, m = 15,prob_m = prob_m, 
                     increase = inc, log = log, multiple_node = 20, num_seed = 20,
-                    mode = i, shape = 10, rate = 10,alpha = 0.5)
+                    mode = i, s = 10,alpha = 0.5)
 
 net_stats <- get_statistics(net,deg_threshold = 5, 
                            binning = TRUE, g = 50) 
